// Blacks
$jet: #181818;
$inkstone: #3D3D3D;
$slate: #5D5D5D;
$graphite: #666666;

// Whites
$white: #FFFFFF;
$porcelain: #F7F7F7;
$silk: #CCC;
$warm_gray: #AEA79F;
$ash: #878787;

// Purples
$aubergine: #924D8B;
$purple: #762572;
$light_aubergine: #77216F;
$mid_aubergine: #5E2750;
$dark_aubergine: #2C001E;

// Reds
$red: #c7162b;

// Oranges
$orange: #E95420;

// Yellows
$yellow: #f99b11;

// Greens
$green: #0e8420;

// Blues
$blue: #19B6EE;
$linkblue: #007aa6;
$darkblue: #335280;


// Semantic colors
$accent_bg_color: $orange !default;
$accent_fg_color: $white !default;
