MsdOsdWindow.background.osd {
	border-radius: $window_radius;
  border: 1px solid transparentize(white, 0.85);
  background-color: $osd_bg_color;
  color: $osd_fg_color;

  .trough {
    border-radius: $button_radius;
    border: none;
    background: darken($osd_fg_color, 70%);
  }

  .progressbar {
    border-radius: $button_radius;
    background-color: $osd_fg_color;
    border: none;
  }
}

.background.osd {
	color: $osd_fg_color;
	background-image: none;
	background-color: $osd_bg_color;
  border-radius: $window_radius;
  border: 1px solid transparentize(white, 0.85);

  :selected {
    background-color: $selected_bg_color;
  }
}
