.xfce4-panel.background {
  border: none; 
  background-color: $panel_bg_color;
  color: $panel_fg_color;

  button {
    padding: 0;
    min-height: 12px;
    min-width: 12px;
    border-radius: 0;
    color: $panel_fg_color;
    @include button(undecorated);

    &:disabled {
      background-color: transparent;
      color: transparentize($panel_fg_color, 0.8);
    }
    
    &:hover:not(:active):not(:checked) {
    color: $panel_fg_color;
    background-color: lighten($panel_bg_color, 20%);
    background-image: none;
    box-shadow: none;
  }

    &:checked {
      background-color: lighten($panel_bg_color, 30%);
      color: $panel_fg_color;
      box-shadow: inset 0 -2px $selected_bg_color;

      &:disabled {
        @include button(undecorated);
        color: transparentize($panel_fg_color, 0.8);
      }
    }
    entry { caret-color: $text_color; }
    menu {
        -gtk-icon-effect: none;

        text-shadow: none;
        // Theme pulseaudio-plugin's mpris buttons
        .linked button {
            @extend %linked;
            @include button(normal, $menu_color, $text_color);
            &:disabled {
              @include button(insensitive);
              border-color: transparentize($borders_color, 0.5);
            }
        }
    }
  }

}
