/*************************** Check and Radio buttons * */
row label.subtitle { font-size: smaller; opacity: 0.55; text-shadow: none; }

row > box.header { margin-left: 12px; margin-right: 12px; min-height: 50px; }

row > box.header > box.title { margin-top: 8px; margin-bottom: 8px; }

row.expander { background-color: transparent; }

row.expander list.nested > row { background-color: alpha(#f6f5f4, 0.5); border-color: alpha(#cdc7c2, 0.7); border-style: solid; border-width: 1px 0px 0px 0px; }

row.expander image.expander-row-arrow { transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

row.expander:checked image.expander-row-arrow { -gtk-icon-transform: rotate(0turn); }

row.expander:not(:checked) image.expander-row-arrow { opacity: 0.55; text-shadow: none; }

row.expander:not(:checked) image.expander-row-arrow:dir(ltr) { -gtk-icon-transform: rotate(-0.25turn); }

row.expander:not(:checked) image.expander-row-arrow:dir(rtl) { -gtk-icon-transform: rotate(0.25turn); }

row.expander:checked image.expander-row-arrow:not(:disabled) { color: #3584e4; }

row.expander image.expander-row-arrow:disabled { color: #929595; }

flap > dimming, deck > dimming, leaflet > dimming { background: rgba(0, 0, 0, 0.12); }

flap > border, deck > border, leaflet > border { min-width: 1px; min-height: 1px; background: rgba(0, 0, 0, 0.05); }

flap > shadow, deck > shadow, leaflet > shadow { min-width: 56px; min-height: 56px; }

flap > shadow.left, deck > shadow.left, leaflet > shadow.left { background-image: linear-gradient(to right, rgba(0, 0, 0, 0.05), rgba(0, 0, 0, 0.01) 40px, rgba(0, 0, 0, 0) 56px), linear-gradient(to right, rgba(0, 0, 0, 0.03), rgba(0, 0, 0, 0.01) 7px, rgba(0, 0, 0, 0) 24px); }

flap > shadow.right, deck > shadow.right, leaflet > shadow.right { background-image: linear-gradient(to left, rgba(0, 0, 0, 0.05), rgba(0, 0, 0, 0.01) 40px, rgba(0, 0, 0, 0) 56px), linear-gradient(to left, rgba(0, 0, 0, 0.03), rgba(0, 0, 0, 0.01) 7px, rgba(0, 0, 0, 0) 24px); }

flap > shadow.up, deck > shadow.up, leaflet > shadow.up { background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.05), rgba(0, 0, 0, 0.01) 40px, rgba(0, 0, 0, 0) 56px), linear-gradient(to bottom, rgba(0, 0, 0, 0.03), rgba(0, 0, 0, 0.01) 7px, rgba(0, 0, 0, 0) 24px); }

flap > shadow.down, deck > shadow.down, leaflet > shadow.down { background-image: linear-gradient(to top, rgba(0, 0, 0, 0.05), rgba(0, 0, 0, 0.01) 40px, rgba(0, 0, 0, 0) 56px), linear-gradient(to top, rgba(0, 0, 0, 0.03), rgba(0, 0, 0, 0.01) 7px, rgba(0, 0, 0, 0) 24px); }

flap > outline, deck > outline, leaflet > outline { min-width: 1px; min-height: 1px; background: rgba(255, 255, 255, 0.2); }

avatar { border-radius: 9999px; -gtk-outline-radius: 9999px; font-weight: bold; }

avatar.color1 { background-image: linear-gradient(#83b6ec, #337fdc); color: #cfe1f5; }

avatar.color2 { background-image: linear-gradient(#7ad9f1, #0f9ac8); color: #caeaf2; }

avatar.color3 { background-image: linear-gradient(#8de6b1, #29ae74); color: #cef8d8; }

avatar.color4 { background-image: linear-gradient(#b5e98a, #6ab85b); color: #e6f9d7; }

avatar.color5 { background-image: linear-gradient(#f8e359, #d29d09); color: #f9f4e1; }

avatar.color6 { background-image: linear-gradient(#ffcb62, #d68400); color: #ffead1; }

avatar.color7 { background-image: linear-gradient(#ffa95a, #ed5b00); color: #ffe5c5; }

avatar.color8 { background-image: linear-gradient(#f78773, #e62d42); color: #f8d2ce; }

avatar.color9 { background-image: linear-gradient(#e973ab, #e33b6a); color: #fac7de; }

avatar.color10 { background-image: linear-gradient(#cb78d4, #9945b5); color: #e7c2e8; }

avatar.color11 { background-image: linear-gradient(#9e91e8, #7a59ca); color: #d5d2f5; }

avatar.color12 { background-image: linear-gradient(#e3cf9c, #b08952); color: #f2eade; }

avatar.color13 { background-image: linear-gradient(#be916d, #785336); color: #e5d6ca; }

avatar.color14 { background-image: linear-gradient(#c0bfbc, #6e6d71); color: #d8d7d3; }

avatar.contrasted { color: #fff; }

avatar.image { background: none; }

viewswitchertitle viewswitcher { margin-left: 12px; margin-right: 12px; }

statuspage > scrolledwindow > viewport > box { margin: 36px 12px; }

statuspage > scrolledwindow > viewport > box > clamp:not(:last-child) > box { margin-bottom: 36px; }

statuspage > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) { margin-bottom: 36px; }

statuspage > scrolledwindow > viewport > box > clamp > box > .title:not(:last-child) { margin-bottom: 12px; }

window.preferences > deck > deck > box > stack > stack > scrolledwindow > viewport > clamp, preferencespage > scrolledwindow > viewport > clamp { margin: 0 12px; margin-bottom: 24px; }

window.preferences > deck > deck > box > stack > stack > scrolledwindow > viewport > clamp > list, window.preferences > deck > deck > box > stack > stack > scrolledwindow > viewport > clamp > box > preferencesgroup, preferencespage > scrolledwindow > viewport > clamp > list, preferencespage > scrolledwindow > viewport > clamp > box > preferencesgroup { margin-top: 24px; }

preferencesgroup > box > label:not(:first-child) { margin-top: 6px; }

preferencesgroup > box > box:not(:first-child) { margin-top: 12px; }

tabbar .tab-indicator:not(.clickable) { background: none; box-shadow: none; border-color: transparent; }
