#MozillaGtkWidget.background {

    // Adapt scrollbars a bit more to the GTK Scrollbar styling
    scrollbar {
        background-color: transparent;
        border-color: transparent;

        slider {
            background-color: darken($scrollbar_slider_color, 10%);

            &:hover {
                background-color: darken($scrollbar_slider_hover_color, 10%);
            }

            &:hover:active {
                background-color: $scrollbar_slider_active_color;
            }

            &:backdrop {
                background-color: $backdrop_scrollbar_slider_color;
            }

            &:disabled {
                background-color: transparent;
            }
        }

        trough {
            background-color: transparentize($bg_color, 0.8);
        }
    }
}

normal-button {
    @include button(normal);

    &:hover {
        @include button(hover);
    }

    &:active {
        @include button(active)
    }

    &:disabled {
        @include button(insensitive);
    }
}
