// Search entry

.search-entry {
  border-radius: $forced_circular_radius;
  margin-top: $base_padding * 4; // Yaru change: realign search entry due to fixed panel opacity
  margin-bottom: $base_padding * 2; // Yaru change: realign search entry due to fixed panel opacity
  width: 24em;
  

  @extend %system_entry;

  // Yaru: Use light text for the search hint
  @if ($variant =='light') {
    StLabel.hint-text {
      color: transparentize($system_fg_color, 0.2);
    }
  }

  .search-entry-icon {
    icon-size: $scalable_icon_size;
    margin-top: 2px; // center vertically
    padding: 0 $base_margin;
  }
}
