.nemo-properties-dialog {
    .dialog-action-box .dialog-action-area {
        // add margin to preferences buttons
        margin: 2px 6px 4px;
    }

    toolbar stackswitcher.linked button {
        margin-right: 0;

        &:backdrop {
            color: $backdrop_fg_color;
            background-color: $backdrop_bg_color;
        }
    }
}

.nemo-window {
    .sidebar {
        scrolledwindow.frame.nemo-places-sidebar {
            // get rid of double border in sidebar
            border: none;
        }

        viewport.frame box.vertical treeview.view.places-treeview {
            // use sidebar bg color
            background-image: image($sidebar_bg_color);
            border-radius: 0; // get rid of weird radius on selected rows

            &:backdrop {
                background-image: image($backdrop_sidebar_bg_color);
            }

            &:selected {
                background: $selected_bg_color;
            }

            &:not(:selected) {
                &:not(:backdrop):hover {
                    background-image: image($base_hover_color);
                }
            }
        }

    }

    .nemo-inactive-pane .view,
    .nemo-inactive-pane iconview {
        // Shades the background of the inactive pane
        background-color: $backdrop_bg_color;
    }

    .nemo-window-pane {
        widget.entry {
            // Add border around rename text entry
            border: 1px solid;
            border-radius: 3px;
            color: $fg_color;
            border-color: $selected_bg_color;
            background-color: $bg_color;
        }

        widget.entry:selected {
            // Add highlighting to selected text in rename text entry
            border: 1px solid;
            border-radius: 3px;
            color: $selected_fg_color;
            border-color: $selected_bg_color;
            background-color: $selected_bg_color;
        }
    }

    .view {

        // imports nautilus tweaks
        // dim icons in backdrop
        &:backdrop {
            @extend %dim_icons_in_backdrop;
        }
    }

    toolbar.horizontal.primary-toolbar {
        // add border under toolbar
        border-bottom: 1px solid $borders_color;

        widget.linked.raised button {

            // use proper icons for next and left in stackswitcher-like pathbar
            &:first-child widget {
                -gtk-icon-source: -gtk-icontheme('go-previous-symbolic');
            }

            &:last-child widget {
                -gtk-icon-source: -gtk-icontheme('go-next-symbolic');
            }
        }

        toolitem box widget * {
            // reset toolbar button dimensions
            min-height: 0;
            min-width: 0;
        }

        .linked button {
            // link linked buttons
            margin-right: 0;
        }

        button {

            // return non-flat buttons
            @each $state,
            $t in ("", "normal"),
            (":hover", "hover"),
            (":active, &:checked", "active"),
            (":disabled", "insensitive"),
            (":disabled:active, &:disabled:checked", "insensitive-active"),
            (":backdrop", "backdrop"),
            (":backdrop:active, &:backdrop:checked", 'backdrop-active'),
            (":backdrop:disabled", 'backdrop-insensitive'),
            (":backdrop:disabled:active, &:backdrop:disabled:checked", 'backdrop-insensitive-active') {
                &#{$state} {
                    @include button($t)
                }
            }
        }
    }
}
