// Axing the border-radii for classic (not csd) dialog buttons
// So we don't end up with rounded buttons in a squared dialog frame
messagedialog.background:not(.csd) {
  .dialog-action-area button {
    border-radius: $button_radius;
    -gtk-outline-radius: $button_radius;
    border: 1px solid $borders_color;
    margin: 4px;
    margin-bottom: 6px;
    &:first-child {
      margin-left: 6px;
    }
    &:last-child {
      margin-right: 6px;
    }
  }
}

// Removes roundness and highlight from
// Headerbars that are not the last vertical top element
// of the window
.background:not(.csd) headerbar:not(.titlebar) {
  border-radius: 0;
  box-shadow: none;
}
