.brisk-menu {
    .apps-list, .categories-list, entry {
      margin: 4px;
    }
  
    .apps-list, .categories-list {
      border-radius: $menu_radius;
      row:selected { background-color: $selected_bg_color; color: $selected_fg_color; }
    }
  
    /* classic session button */
    button.flat.session-button {
        padding: 5px 6px;
        min-width: 24px;
    }
  
    scrolledwindow {
      border-width: 1px;
      border-style: solid;
      border-color: transparent;
      margin: 4px;
    }
  
    scrollbar {
      background-image: none;
      background-color: transparent;
      border-style: solid;
      border-color: transparent;
    }
  }
  
  // This should move into _tweaks.scss
  // Or best would be adwaita, since there is no :hover for iconview there
  iconview {
    border-radius: $button_radius;
    &:hover {
      background-color: $popover_hover_color;
    }
  }
  
  /* Brisk menu's panel button */
  .mate-panel-menu-bar #PanelApplet button.flat.toggle.brisk-button {
    &, &:hover {
      image {
        margin: 0px;
        padding: 0px;
      }
      background-image: none;
      background-color: transparent;
      padding: 0px;
      margin: 0px;
      border-color: transparent;
      border-radius: 0;
      border-image: none;
      text-shadow: none;
      &:checked {
        box-shadow: inset 0 -3px 0 0 $selected_bg_color;
      }
    }    
  }
  
  /* mate-keyboard-layout-view, mate-keyboard-layout-chooser */
  /* this way it styles only the border of the keys, the bg of the map itself
     use the .view class */
  matekbd-keyboard-drawing {
      background-color: $_base_bg_color;
  }
  
  matekbd-keyboard-drawing:selected {
          background-color: $selected_bg_color;
          color: $selected_fg_color;
  }
  
  #xkb-layout-chooser > box.dialog-vbox > box.vertical > box.vertical > frame > border {
      border-radius: 0px;
  }
  
  scrollbar {
    background-image: none;
    background-color: transparent;
  }
  
  // Axing the border-radii for classic (not csd) dialog buttons
  // So we don't end up with rounded buttons in a squared dialog frame
  messagedialog.background:not(.csd) {
    .dialog-action-area button {
      border-radius: $button_radius;
      -gtk-outline-radius: $button_radius;
      border: 1px solid $borders_color;
      margin: 4px;
      margin-bottom: 6px;
      &:first-child {
        margin-left: 6px;
      }
      &:last-child {
        margin-right: 6px;
      }
    }
  }
