/* override for pavu-control */
window.background.mate-terminal > box.vertical > notebook > header.top,
window.background.mate-terminal > box.vertical > notebook > stack > box {
    border-style: none;
    border-width: 0px;
}

/* vte use hardcoded colors as upstream, ubuntu is patched */
window.background.mate-terminal {

  $_mate_terminal_bg_color: $bg_color;
  $_mate_terminal_fg_color: $fg_color;

  &, menubar, vte-terminal {
    background-color: $_mate_terminal_bg_color;
    color: $_mate_terminal_fg_color;
    &:backdrop {
      color: $_backdrop_base_fg_color;
    }
  }
  scrollbar {
    &, &.vertical {
      &, &:backdrop {
        background-color: transparent;
      }
    }
    
  }

  menubar,
  .menubar {      
    > menuitem {
      &:hover {
        color: $_mate_terminal_fg_color;
      }
    }
  }

  notebook {
    stack box.vertical box.horizontal scrollbar.vertical {
      background-color: $_mate_terminal_bg_color;
    }
   
    tab {
      color: $_mate_terminal_fg_color;
      &:backdrop {
        color: $_backdrop_base_fg_color;
      }
      button {
        &:hover {
          background-image: image($_mate_terminal_bg_color);
          color: $_mate_terminal_fg_color;
          border-color: $_base_border_color;
        }
        &:active {
          background-image: image(darken($_backdrop_base_bg_color, 4%));
          color: darken($_mate_terminal_fg_color, 4%);
          border-color: darken($_base_border_color, 4%);
        }
        
      }
    }
  }
}
