@import 'apps/tweak-tool';
@import 'apps/nautilus';
@import 'apps/gnome-terminal';
@import 'apps/gnome-software';
@import 'apps/gedit';
@import 'apps/gnome-disks';
@import 'apps/nemo';
@import 'apps/not-csd';
@import 'apps/gnome-todo';
@import 'apps/guake';
@import 'apps/firefox';
@import 'apps/ubiquity';
@import 'apps/geary';
@import 'apps/usb-creator-gtk';
@import 'apps/evolution';
@import 'apps/unity7';
@import 'apps/xfce';
@import 'apps/mate'; // Have to be included before all other mate files due to vars
@import 'apps/brisk-menu';
@import 'apps/caja';
@import 'apps/mate-control-center';
@import 'apps/mate-multimedia-osd';
@import 'apps/mate-terminal';
@import 'apps/ding';
@import 'apps/evince';
