window.background.caja-navigation-window #Toolbar:backdrop { background-color: $backdrop_bg_color; }

.caja-pathbar button {
  min-width: 24px;
  border-radius: 0;
  border-right-width: 0;
  margin-right: -3px;
}

.caja-pathbar button.slider-button:nth-child(odd) {
    border-radius: $button_radius 0px 0px $button_radius;
}

.caja-pathbar button.slider-button:nth-child(even) {
    border-radius: 0 $button_radius $button_radius 0;
    border-right-width: 1px;
}

// Removes roundness and highlight from
// Headerbars that are not the last vertical top element
// of the window
.background:not(.csd) headerbar:not(.titlebar) {
  border-radius: 0;
  box-shadow: none;
}

// style mate control center
#slab_section_style2.vertical:dir(ltr)  {
  background-color: $base_color; 
  &, label {
    &, &:dir(ltr) {
      color: $text_color;
      &:backdrop { color: $backdrop_text_color; }
    }    
  }
}

// Style mate panel pull down terminal search bar
window#Main.background {
  $_pull_down_terminal_border_color: if($variant=='light', $borders_color, lighten(desaturate($base_color, 100%), 14%));
  #search {
    background: $base_color;
    color: $fg_color;
    box-shadow: inset 100px 100px $base_color; // very dirty hack, otherwise we can't set the bg
    border-bottom: 1px solid $_pull_down_terminal_border_color;
    entry { border-color: $_pull_down_terminal_border_color; }
  }
}

// Fix for invivible caret navigation in dark theme
.caja-navigation-window,
.caja-desktop-window {
  widget.view widget.entry {
    background: if($variant=="light", darken($bg_color, 5%), lighten($bg_color, 5%));
    color: $fg_color;
    border-color: $borders_color;
  
    &:selected {
      background: $selected_bg_color;
      color: $selected_fg_color;
    }
  }
}
