#live_installer {
    #title_eventbox {
        background-color: $bg_color;
        color: $fg_color;

        &:backdrop {
            background-color: $backdrop_bg_color;
            color: $backdrop_fg_color;
        }
    }

    #dot_grid progressbar {
        border-radius: 100%;
        padding: 1px;
        padding-top: 2px;
        background-color: white;
        border: 1px solid $progress_bg_color;

        .empty {
            border-radius: 100%;
            background-color: white;
            padding: 0px;
        }

        .full progress {
            border-radius: 100%;
            padding: 1px;
            padding-top: 2px;
            margin-bottom: 2px;
        }
    }
}

#dialog-action_area1 {
    padding-bottom: 5px;
    padding-right: 5px
}
