$_terminal_bg_color: #300A24;
$_terminal_fg_color: white;

terminal-window {

    // use unity 8 colors
    // only colors, let everything else be inherited
    .terminal-screen {
        // inherits from .background
        background-color: $_terminal_bg_color;
        color: $_terminal_fg_color;

        &:backdrop {
            background-color: lighten($_terminal_bg_color, 2%);
            color: $backdrop_selected_fg_color;
        }
    }

    notebook {
        scrollbar {
            // inherits from scrollbar
            background-color: transparent;
            border-color: transparent;

            &:backdrop {
                background-color: transparent;
                border-color: transparent
            }

            slider {
                // avoids scrollbar protruding from the terminal window on wayland session
                // workaround for https://bugs.launchpad.net/ubuntu/+source/gnome-terminal/+bug/1720651
                margin: 0;
                border-width: 3px;

                &:backdrop {
                    background-color: gtkalpha(currentColor, 0.1);
                }

                &:disabled {
                    background-color: transparent;
                }
            }

            &.dragging,
            &.hovering {
                background-color: transparent;
            }
        }
    }
}
