/* Buttons */

.button {
  @extend %button;
  // uses scalable value since it's a text element
  min-height: to_em(22px);

  // default style
  &.default {
    @extend %default_button;
  }
  // flat style
  &.flat {
    @extend %flat_button;
  }
}

.icon-button {
  @extend %button;

  border-radius: $forced_circular_radius; // is circular
  padding: $scaled_padding * 2;
  min-height: $scalable_icon_size;

  StIcon {
    icon-size: $scalable_icon_size;
    -st-icon-style: symbolic;
  }

  // default style
  &.default {
    @extend %default_button;
  }

  // flat style
  &.flat {
    @extend %flat_button;
  }
}
