
//Used as update count in GNOME software
.counter-label {
    margin-top: 2px;
    margin-bottom: 2px;
    border-width: 0px;
    padding-left: 2px;
    padding-right: 2px;
    box-shadow: inset 0 0 10px 10px $success_color;
}
