.gedit-bottom-panel-paned notebook>header {
    background: if($variant==light, $porcelain, $bg_color);
}

.gedit-bottom-panel-paned~statusbar {
    // give gedit's bottom panel a border
    border-top: 1px solid $borders_color;

    &:backdrop {
        border-color: $backdrop_borders_color;
    }
}

.gedit-search-slider {
    // gives gedit search entry some padding and a border
    // otherwise it's right under the headerbar
    background: $bg_color;
    border: 1px solid $borders_color;
    border-top-style: none;
    padding: 4px 8px;
    border-radius: 0 0 5px 5px; // same radius as tooltips

    &:backdrop {
        background-color: $backdrop_bg_color;
        border-color: $backdrop_borders_color;
    }
}

.gedit-search-entry-occurrences-tag {
    color: transparentize($fg_color, 0.65);
    border: none; // Removed ugly tag border
    box-shadow: none; // Removed button inset shadow
    margin: 2px;
    padding: 2px;
}

.gedit-document-panel {
    // 'documents' pane

    background-color: $bg_color;

    row.activatable {
        padding: 6px;
    }

    row button {
        // 'close' button
        min-width: 22px;
        min-height: 22px;
        padding: 0;
        margin: 0;
        border: none;
    }

    row:hover button {
        &:hover {
            background-color: rgba($fg_color, 0.15);
        }

        &:active {
            background-color: rgba($fg_color, 0.25);
        }
    }

    row:hover:selected button:hover {
        color: $selected_fg_color;
    }
}
