// Style DING (Desktop Icons NG) menus like GS ones

menu.desktopmenu {
    menuitem {
        margin: 0 .25rem;
        padding: .5rem;
        border-radius: $menu_radius - 1px;
    }
    
    separator {
        margin: .25rem 1rem;
    }
}
