//
// High Contrast theme definitions
//
// this is an always dark theme, so no 'light' theme conditions

@import '_palette.scss';

// Yaru change: hard include gnome palette because include and symlink doesn't work with Github CI
//GNOME Color Palette
$blue_1: #99c1f1;
$blue_2: #62a0ea;
$blue_3: #3584e4;
$blue_4: #1c71d8;
$blue_5: #1a5fb4;
$green_1: #8ff0a4;
$green_2: #57e389;
$green_3: #33d17a;
$green_4: #2ec27e;
$green_5: #26a269;
$yellow_1: #f9f06b;
$yellow_2: #f8e45c;
$yellow_3: #f6d32d;
$yellow_4: #f5c211;
$yellow_5: #e5a50a;
$orange_1: #ffbe6f;
$orange_2: #ffa348;
$orange_3: #ff7800;
$orange_4: #e66100;
$orange_5: #c64600;
$red_1: #f66151;
$red_2: #ed333b;
$red_3: #e01b24;
$red_4: #c01c28;
$red_5: #a51d2d;
$purple_1: #dc8add;
$purple_2: #c061cb;
$purple_3: #9141ac;
$purple_4: #813d9c;
$purple_5: #613583;
$brown_1: #cdab8f;
$brown_2: #b5835a;
$brown_3: #986a44;
$brown_4: #865e3c;
$brown_5: #63452c;
$light_1: #ffffff;
$light_2: #f6f5f4;
$light_3: #deddda;
$light_4: #c0bfbc;
$light_5: #9a9996;
$dark_1: #77767b;
$dark_2: #5e5c64;
$dark_3: #3d3846;
$dark_4: #241f31;
$dark_5: #000000;

@import '_default-colors.scss';

// global colors
$base_color: $dark_5;
$bg_color: lighten($base_color, 10%);
$fg_color: $light_1;

// OSD elements
$osd_fg_color: $light_1;
$osd_bg_color: $base_color;

// system elements
$system_base_color: $dark_5;
$system_fg_color: $light_1;

// panel colors
$panel_bg_color: $dark_5;
$panel_fg_color: $light_1;

// card elements
$card_bg_color: $bg_color;
$card_shadow_color: transparent;
$card_shadow_border_color: $card_bg_color;

//
// Derived Colors
//
// colors based on the global defines above

// borders
$borders_color: transparentize($fg_color, $border_opacity);
$outer_borders_color: $borders_color;

// osd colors
$osd_borders_color: transparentize($osd_fg_color, 0.8);
$osd_outer_borders_color: $osd_borders_color;

// system colors
$system_bg_color: lighten($system_base_color, 5%);
$system_borders_color: transparentize($system_fg_color, .9);
$system_insensitive_fg_color: mix($system_bg_color, $system_fg_color, 30%);
$system_overlay_bg_color: mix($system_bg_color, $system_fg_color, 90%);

// insensitive state
$insensitive_fg_color: $fg_color;
$insensitive_bg_color: mix($bg_color, $base_color, 60%);
$insensitive_borders_color: $borders_color;

// checked state
$checked_bg_color: lighten($bg_color, 18%);
$checked_fg_color: lighten($fg_color, 18%);

// hover state
$hover_bg_color: lighten($bg_color, 20%);
$hover_fg_color: lighten($fg_color, 20%);

// active state
$active_bg_color: lighten($bg_color, 22%);
$active_fg_color: lighten($fg_color, 22%);

// accent colors
$accent_borders_color: st-lighten(-st-accent-color, 30%);

//
// High Contrast specific definitions
//

// color for outline drawn onto all elements (may be a border or a box-shadow)
$hc_inset_color: transparentize($fg_color, 0.6);

// color used in a mixin in _drawing to boost a color's contrast
$hc_mix_color: $light_1;

// the mix factor used to boost contrast of a color in the above mixin
$hc_mix_factor: 87%;

$fg_color_dark: $porcelain;
$bg_color_dark: lighten($jet, 2%);

// Yaru custom definitions
@import '_yaru-default-colors';
@import '_yaru-colors.scss';
