.nautilus-window,
.nautilus-window notebook,
.nautilus-window notebook > stack {
    background: @theme_base_color;
}

.nautilus-empty-state-icon {
    opacity: 0.50;
}

.nautilus-canvas-item {
    border-radius: 5px;
}

.nautilus-canvas-item.thumbnail {
  -gtk-icon-shadow: 0px 1px 2px @borders,
                    1px 0px 0px alpha(@borders, 0.25),
                    -1px 0px 0px alpha(@borders, 0.25),
                    0px 2px 0px alpha(@borders, 0.5);
}

.nautilus-canvas-item.dim-label {
    color: mix (@theme_fg_color, @theme_bg_color, 0.50);
}

.nautilus-canvas-item.dim-label:selected {
    color: mix (@theme_selected_fg_color, @theme_selected_bg_color, 0.20);
}

/* Toolbar */

/* Here we use the .button background-image colors from Adwaita, but ligthen them,
 * since is not possible to use lighten () in common css. */
@keyframes needs_attention_keyframes {
    0% {background-image: linear-gradient(to bottom, #fafafa, #ededed 40%,  #e0e0e0); border-color: @borders; }
    /* can't do animation-direction, so holding the color on two keyframes */
    30% {background-image: linear-gradient(to bottom, @theme_base_color, @theme_base_color, @theme_base_color); border-color: @theme_fg_color; }
    90% {background-image: linear-gradient(to bottom, @theme_base_color, @theme_base_color, @theme_base_color); border-color: @theme_fg_color; }
    100% {background-image: linear-gradient(to bottom, #fafafa, #ededed 40%,  #e0e0e0); border-color: @borders; }
}

.nautilus-operations-button-needs-attention {
  animation: needs_attention_keyframes 2s ease-in-out;
}
.nautilus-operations-button-needs-attention-multiple {
  animation: needs_attention_keyframes 3s ease-in-out;
  animation-iteration-count: 3;
}

/* Remove white background and highlight on hover which GTK adds by default
 * to GtkListBox. TODO: Switch to GtkListView and drop this CSS hack. */
.operations-list,
.operations-list > :hover {
  background: none;
}

.disclosure-button {
  padding-left: 4px;
  padding-right: 4px;
}

/* Path bar */

.nautilus-path-bar scrolledwindow {
  border-radius: 5px 0px 0px 5px;
  border: 1px @borders solid;
  border-right-width: 0px;
  background-color: @theme_bg_color;
}
.nautilus-path-bar scrolledwindow undershoot.left {
  border-radius: 5px 0px 0px 5px;
  background: linear-gradient(to right, @theme_bg_color 6px, alpha(@theme_bg_color, 0) 24px);
}
.nautilus-path-bar scrolledwindow undershoot.right {
  background: linear-gradient(to left, @theme_bg_color 6px, alpha(@theme_bg_color, 0) 24px);
}

.nautilus-path-bar > button,
.path-buttons-box button {
  margin: 0px;
}

.path-buttons-box button {
  background-image: none;
  box-shadow: none;
  border-radius: 5px;
  border-width: 0px;
  -gtk-icon-shadow: none;
}

.path-buttons-box button:not(.current-dir):not(:backdrop):hover {
  background: alpha(@theme_fg_color, 0.15);
  box-shadow: inset 0 0 0 2px @theme_bg_color;
}

.path-buttons-box button:not(.current-dir):not(:backdrop):hover * {
  opacity: 1;
}

/* Make the tags fit into the box */
entry.search > * {
  margin: 5px;
}

/* Sidebar */

.nautilus-window .sidebar-row:selected {
    background: mix(@theme_bg_color, @theme_fg_color, 0.07);
}

.nautilus-window .sidebar-row:selected,
.nautilus-window .sidebar-row:selected image,
.nautilus-window .sidebar-row:selected label {
    color: mix(@theme_fg_color, @theme_text_color, 0.5);
}

.nautilus-window .sidebar-row:selected:backdrop {
    background: mix(@theme_unfocused_bg_color, @theme_unfocused_fg_color, 0.07);
}

.nautilus-window .sidebar-row:selected:backdrop,
.nautilus-window .sidebar-row:selected:backdrop label {
    color: mix(@theme_unfocused_fg_color, @theme_unfocused_text_color, 0.15);
}

/* Floating status bar */
.floating-bar {
  padding: 1px;
  background-color: @theme_base_color;
  border-width: 1px;
  border-style: solid solid none;
  border-color: @borders;
  border-radius: 8px 8px 0 0;
}

.floating-bar.bottom.left { /* axes left border and border radius */
  border-left-style: none;
  border-top-left-radius: 0;
}
.floating-bar.bottom.right { /* axes right border and border radius */
  border-right-style: none;
  border-top-right-radius: 0;
}

.floating-bar:backdrop {
  background-color: @theme_unfocused_base_color;
  border-color: @unfocused_borders;
}

.floating-bar button {
  padding: 0px;
}

@define-color disk_space_unknown #888a85;
@define-color disk_space_used #729fcf;
@define-color disk_space_free #eeeeec;

.disk-space-display {
    border-style: solid;
    border-width: 2px;
}

.disk-space-display.unknown {
    background-color: @disk_space_unknown;
    border-color: shade(@disk_space_unknown, 0.7);
    color: @disk_space_unknown;
}
.disk-space-display.unknown.border {
    color: shade(@disk_space_unknown, 0.7);
}

.disk-space-display.used {
    background-color: @disk_space_used;
    border-color: shade(@disk_space_used, 0.7);
    color: @disk_space_used;
}
.disk-space-display.used.border {
    color: shade(@disk_space_used, 0.7);
}

.disk-space-display.free {
    background-color: @disk_space_free;
    border-color: shade(@disk_space_free, 0.7);
    color: @disk_space_free;
}
.disk-space-display.free.border {
    color: shade(@disk_space_free, 0.7);
}

/* As a workaround for GtkTreeView showing thick border above first row when
 * horizontal grid lines are enabled, we add them using CSS instead. Exclude the
 * drop targets to let through the default feedback style. */
.nautilus-list-view .view:not(:drop(active)) {
    border-bottom: 1px solid @theme_bg_color;
}

.nautilus-list-view.thumbnail {
  -gtk-icon-shadow: 0px 1px 2px @borders,
                    1px 0px 0px alpha(@borders, 0.25),
                    -1px 0px 0px alpha(@borders, 0.25),
                    0px 2px 0px alpha(@borders, 0.5);
}

.search-information {
  background-color: @theme_selected_bg_color;
  color:white;
  padding:2px;
}

@define-color conflict_bg #fef6b6;

.conflict-row {
    background: @conflict_bg;
    color: black;
}

.conflict-row:hover {
    background-color: shade(@conflict_bg, 0.9);
}

.conflict-row:selected {
  background: @theme_selected_bg_color;
  color: @theme_selected_fg_color;
}

/* Icon view */
flowbox {
  padding: 18px
}

flowboxchild {
  padding: 0px;
}

flowboxchild:selected {
  background-color:transparent;
  outline-color: transparent;
}

flowboxchild .thumbnail {
  margin: 4px;
  box-shadow: 0px 1px 2px 0px alpha(@borders, 0.5),
              0px 0px 0px 1px alpha(@borders, 0.5),
              0px 2px 0px 0px alpha(@borders, 0.5);
  border-radius: 2px;
}

.icon-ui-labels-box {
  padding: 2px 4px;
  border-radius: 4px;
}

flowboxchild:selected .icon-ui-labels-box {
  color: @theme_selected_fg_color;
  background-color: @theme_selected_bg_color;
}

flowboxchild:selected image {
  -gtk-icon-effect: dim; /* GTK 3 only */
  /* GTK 4 TODO: Replace previous line with the following one:
  -gtk-icon-filter: opacity(0.5);
  */
  -gtk-icon-shadow: 0px 0px @theme_selected_bg_color;
}

