/* Workspace pager */

// thumbnails in overview
.workspace-thumbnails {
  visible-width: 32px; //amount visible before hover
  spacing: $base_padding;
  padding: $base_padding;
  border-color: transparent; // Yaru: adapt the workspace osd border to the dock border

  .workspace-thumbnail {
    color: $system_fg_color;
    background-color: lighten($system_bg_color, 10%);
    border-radius: $base_border_radius * 0.5;
    border: 1px solid transparent;

    background-color: $system_overlay_bg_color; // Yaru: use same background as dash
    border: 1px solid $system_borders_color; // Yaru: use same border as dash

    @if $contrast == 'high' {
      border-color: $hc_inset_color;
    }
  }

  // drag and drop indicator
  .placeholder {
    background-image: url("resource:///org/gnome/shell/theme/workspace-placeholder.svg");
    background-size: contain;
    width: 18px;
  }
}

// selected indicator
.workspace-thumbnail-indicator {
  border: 3px solid -st-accent-color;
  border: 2px solid -st-accent-color; // Yaru: we detached focus from selected
  border-radius: $base_border_radius;
}
