/* Entries */

StEntry {
  @extend %entry;

  StIcon.capslock-warning {
    icon-size: $scalable_icon_size;
    warning-color: $warning_color;
    padding: 0 $base_margin;
  }

  StIcon.peek-password {
    icon-size: $scalable_icon_size;
    padding: 0 $base_margin;
  }

  StLabel.hint-text {
    margin-left: $base_margin * 0.5;
  }
}
