$wm_border_unfocused: none;
$wm_border_focused: if($variant=='light', transparentize(black, 0.9), transparentize($borders_color, 0.1));
$titlebar_bg_color: if($variant=='light', darken($porcelain, 9%), lighten($jet, 4%));
$titlebar_fg_color: if($variant=='light', $inkstone, $porcelain);

UnityDecoration {
    -UnityDecoration-extents: 32px 0px 0px 0px;
    -UnityDecoration-input-extents: 10px;

    -UnityDecoration-shadow-offset-x: 1px;
    -UnityDecoration-shadow-offset-y: 1px;
    -UnityDecoration-active-shadow-color: transparentize(black, 0.5);
    -UnityDecoration-active-shadow-radius: 10px;
    -UnityDecoration-inactive-shadow-color: transparentize(black, 0.999);
    -UnityDecoration-inactive-shadow-radius: 0px;

    -UnityDecoration-glow-size: 0px;
    -UnityDecoration-glow-color: $selected_bg_color;

    -UnityDecoration-title-indent: 0px;
    -UnityDecoration-title-fade: 0px;
    -UnityDecoration-title-alignment: 0.5;

    // Unity "titlebars"
    .top {
        border: none;
        border-radius: $window_radius $window_radius 0 0;
        // padding used for the min/max/close titlebuttons
        padding: 1px (4px + 3px) 0 (4px + 3px);
        background-color: $titlebar_bg_color;
        color: $titlebar_fg_color;
        text-shadow: none;
        box-shadow: inset 0 1px lighten($titlebar_bg_color, 8%);

        &:hover {
            // nothing changes here
        }

        &:backdrop {
            border: none;
            background-color: $backdrop_bg_color;
            color: mix($titlebar_fg_color, lighten($titlebar_bg_color, 5%), 70%);
            box-shadow: inset 0 1px transparentize(lighten($titlebar_bg_color, 8%), 0.4);
      
            transition: $backdrop_transition;
        }
    }

    // this is the window border outside of the titlebar!
    .left,
    .right,
    .bottom {
        border: none;
        background-color: transparent;

        &:backdrop {
            background-color: transparent;
        }
    }
}

// unity 7 top panel - equivalent to the gnome panel
UnityPanelWidget,
.unity-panel {
    background-color: $panel_bg_color;
    color: $panel_fg_color;
    border: 0;
}

.unity-panel {

    &.menuitem,
    .menuitem {
        border-width: 0 1px;
        color: $panel_fg_color;
        background-color: transparent;

        &:hover,
        *:hover {
            box-shadow: inset 0 -2px 0 0 $selected_bg_color;
            background-color: transparent;
            color: $panel_fg_color;
        }
    }
}

SheetStyleDialog.unity-force-quit {
    background-color: $bg_color;
}
