// checkbox is clipped but this is undetectable till it gets keyboard focus
// so we're pushing it to the right to have the focus ring be displayed properly
assistant.background scrolledwindow .vertical checkbutton {
    margin-left: 1px
}
