// Named Colors

// base colors
$_base_color_dark: #222226;
$_base_color_light: #fafafb;

// accent colors
$accent_color: if($variant== 'light', -st-accent-color, st-mix(-st-accent-color, $light_1, 60%));

// colors for destructive elements
$destructive_bg_color: if($variant == 'light', $red_3, $red_4);
$destructive_fg_color: $light_1;
$destructive_color: $destructive_bg_color;

// colors for levelbars, entries, labels and infobars
$success_bg_color: if($variant == 'light', $green_4, $green_5);
$success_fg_color: $light_1;
$success_color: $success_bg_color;

$warning_bg_color: if($variant == 'light', $yellow_5, #cd9309); // uses darker off-palette yellow
$warning_fg_color: transparentize(black, .2);
$warning_color: $warning_bg_color;

$error_bg_color: if($variant == 'light', $red_3, $red_4);
$error_fg_color: $light_1;
$error_color: $error_bg_color;

// link colors
$link_color: if($variant == 'light', st-darken(-st-accent-color, 10%), st-lighten(-st-accent-color, 20%));
$link_visited_color: st-transparentize($link_color, .6);

// special cased widget definitions
$background_mix_factor: if($variant == 'light', 12%, 9%); // used to boost the color of backgrounds in different variants

// shadows
$shadow_color: if($variant == 'light', rgba(0,0,0,.05), rgba(0,0,0,0.2));
$text_shadow_color: if($variant == 'light', rgba(255,255,255,0.3), rgba(0,0,0,0.2));

// border opacities
$border_opacity: if($variant == 'light', .85, .9); // change the border opacity in different variants
$focus_border_opacity: .2;

// High Contrast overrides
@if $contrast == 'high' {
    // increase border opacity
    $border_opacity: .5;
    $focus_border_opacity: .1;
    // remove shadows
    $shadow_color: transparent;
    $text_shadow_color: transparent;
}
